@@ -1,35 +1,23 @@
-/* This file is part of the KDE project
-   Copyright (C) 1999-2006 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1999-2006 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KFILEITEM_H
 #define KFILEITEM_H
 
 #include "kiocore_export.h"
-#include <kio/global.h>
-#include <kacl.h>
-#include <kio/udsentry.h>
 #include <QDateTime>
-#include <QUrl>
 #include <QFile>
+#include <QUrl>
+#include <kacl.h>
+#include <kio/global.h>
+#include <kio/udsentry.h>
 
-#include <QMimeType>
 #include <QList>
+#include <QMimeType>
 #include <qplatformdefs.h>
 
 class KFileItemPrivate;
@@ -40,7 +28,7 @@ class KFileItemPrivate;
  * A KFileItem is a generic class to handle a file, local or remote.
  * In particular, it makes it easier to handle the result of KIO::listDir
  * (UDSEntry isn't very friendly to use).
- * It includes many file attributes such as mimetype, icon, text, mode, link...
+ * It includes many file attributes such as MIME type, icon, text, mode, link...
  *
  * KFileItem is implicitly shared, i.e. it can be used as a value and copied around at almost no cost.
  */
@@ -59,13 +47,13 @@ public:
         // warning: don't change without looking at the Private class
         ModificationTime = 0,
         AccessTime = 1,
-        CreationTime = 2
-                       //ChangeTime
+        CreationTime = 2,
+        // ChangeTime
     };
 
     enum MimeTypeDetermination {
         NormalMimeTypeDetermination = 0,
-        SkipMimeTypeFromContent
+        SkipMimeTypeFromContent,
     };
 
     /**
@@ -79,7 +67,7 @@ public:
      *
      * @param entry the KIO entry used to get the file, contains info about it
      * @param itemOrDirUrl the URL of the item or of the directory containing this item (see urlIsDirectory).
-     * @param delayedMimeTypes specifies if the mimetype of the given
+     * @param delayedMimeTypes specifies if the MIME type of the given
      *       URL should be determined immediately or on demand.
      *       See the bool delayedMimeTypes in the KDirLister constructor.
      * @param urlIsDirectory specifies if the url is just the directory of the
@@ -88,9 +76,7 @@ public:
      * When creating KFileItems out of the UDSEntry emitted by a KIO list job,
      * use KFileItem(entry, listjob->url(), delayedMimeTypes, true);
      */
-    KFileItem(const KIO::UDSEntry &entry, const QUrl &itemOrDirUrl,
-              bool delayedMimeTypes = false,
-              bool urlIsDirectory = false);
+    KFileItem(const KIO::UDSEntry &entry, const QUrl &itemOrDirUrl, bool delayedMimeTypes = false, bool urlIsDirectory = false);
 
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
@@ -103,28 +89,27 @@ public:
      * Set to KFileItem::Unknown if you don't know the mode or the permission.
      * @param url the file url
      *
-     * @param delayedMimeTypes specify if the mimetype of the given URL
+     * @param delayedMimeTypes specify if the MIME type of the given URL
      *       should be determined immediately or on demand
      * @deprecated since 5.0. Most callers gave Unknown for mode and permissions,
      * so just port to KFileItem(url) and setDelayedMimeTypes(true) if necessary.
      */
     KIOCORE_DEPRECATED_VERSION(5, 0, "See API docs")
-    KFileItem(mode_t mode, mode_t permissions, const QUrl &url,
-              bool delayedMimeTypes = false);
+    KFileItem(mode_t mode, mode_t permissions, const QUrl &url, bool delayedMimeTypes = false);
 #endif
 
     /**
-     * Creates an item representing a file, for which the mimetype is already known.
+     * Creates an item representing a file, for which the MIME type is already known.
      * @param url the file url
-     * @param mimeType the name of the file's mimetype
+     * @param mimeType the name of the file's MIME type
      * @param mode the mode (S_IFDIR...)
      */
     KFileItem(const QUrl &url, const QString &mimeType = QString(), mode_t mode = KFileItem::Unknown); // KF6 TODO: explicit!
 
     /**
-     * Creates an item representing a file, with the option of skipping mime type determination.
+     * Creates an item representing a file, with the option of skipping MIME type determination.
      * @param url the file url
-     * @param mimeTypeDetermination the mode of determining the mime type:
+     * @param mimeTypeDetermination the mode of determining the MIME type:
      *       NormalMimeTypeDetermination by content if local file, i.e. access the file,
      *                                   open and read part of it;
      *                                   by QMimeDatabase::MatchMode::MatchExtension if not local.
@@ -138,7 +123,7 @@ public:
     /**
      * Copy constructor
      */
-    KFileItem(const KFileItem&);
+    KFileItem(const KFileItem &);
 
     /**
      * Destructor
@@ -149,18 +134,18 @@ public:
      * Move constructor
      * @since 5.43
      */
-    KFileItem(KFileItem&&);
+    KFileItem(KFileItem &&);
 
     /**
      * Copy assignment
      */
-    KFileItem& operator=(const KFileItem&);
+    KFileItem &operator=(const KFileItem &);
 
     /**
      * Move assignment
      * @since 5.43
      */
-    KFileItem& operator=(KFileItem&&);
+    KFileItem &operator=(KFileItem &&);
 
     /**
      * Throw away and re-read (for local files) all information about the file.
@@ -169,14 +154,14 @@ public:
     void refresh();
 
     /**
-     * Re-reads mimetype information.
-     * This is called when the mimetype database changes.
+     * Re-reads MIME type information.
+     * This is called when the MIME type database changes.
      */
     void refreshMimeType();
 
     /**
-     * Sets mimetype determination to be immediate or on demand.
-     * Call this after the constructor, and before using any mimetype-related method.
+     * Sets MIME type determination to be immediate or on demand.
+     * Call this after the constructor, and before using any MIME-type-related method.
      * @since 5.0
      */
     void setDelayedMimeTypes(bool b);
@@ -398,25 +383,25 @@ public:
     QString name(bool lowerCase = false) const;
 
     /**
-     * Returns the mimetype of the file item.
+     * Returns the MIME type of the file item.
      * If @p delayedMimeTypes was used in the constructor, this will determine
-     * the mimetype first. Equivalent to determineMimeType()->name()
-     * @return the mime type of the file
+     * the MIME type first. Equivalent to determineMimeType()->name()
+     * @return the MIME type of the file
      */
     QString mimetype() const;
 
     /**
-     * Returns the mimetype of the file item.
+     * Returns the MIME type of the file item.
      * If delayedMimeTypes was used in the constructor, this will determine
-     * the mimetype first.
-     * @return the mime type
+     * the MIME type first.
+     * @return the MIME type
      */
     QMimeType determineMimeType() const;
 
     /**
-     * Returns the currently known mimetype of the file item.
-     * This will not try to determine the mimetype if unknown.
-     * @return the known mime type
+     * Returns the currently known MIME type of the file item.
+     * This will not try to determine the MIME type if unknown.
+     * @return the known MIME type
      */
     QMimeType currentMimeType() const;
 
@@ -427,9 +412,9 @@ public:
     bool isFinalIconKnown() const;
 
     /**
-     * @return true if we have determined the mimetype of this file already,
+     * @return true if we have determined the MIME type of this file already,
      * i.e. if determineMimeType() will be fast. Otherwise it will have to
-     * find what the mimetype is, which is a possibly slow operation; usually
+     * find what the MIME type is, which is a possibly slow operation; usually
      * this is delayed until necessary.
      */
     bool isMimeTypeKnown() const;
@@ -443,7 +428,7 @@ public:
 
     /**
      * Returns the full path name to the icon that represents
-     * this mime type.
+     * this MIME type.
      * @return iconName the name of the file's icon
      */
     QString iconName() const;
@@ -553,12 +538,29 @@ public:
      */
     QUrl mostLocalUrl(bool *local = nullptr) const;
 
+    struct MostLocalUrlResult {
+        QUrl url;
+        bool local;
+    };
+
+    /**
+     * Returns a MostLocalUrlResult, with the local Url for this item if possible
+     * (otherwise an empty Url), and a bool that is set to @c true if this Url
+     * does represent a local file otherwise @c false.
+     *
+     * @since 5.84
+     */
+    MostLocalUrlResult isMostLocalUrl() const;
+
 #if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 0)
     /**
      * @deprecated since 5.0 add '&' in front of your boolean argument
      */
     KIOCORE_DEPRECATED_VERSION(5, 0, "Use KFileItem::mostLocalUrl(bool *)")
-    QUrl mostLocalUrl(bool &local) const { return mostLocalUrl(&local); }
+    QUrl mostLocalUrl(bool &local) const
+    {
+        return mostLocalUrl(&local);
+    }
 #endif
 
     /**
@@ -575,8 +577,8 @@ private:
     void setHidden();
 
 private:
-    KIOCORE_EXPORT friend QDataStream &operator<< (QDataStream &s, const KFileItem &a);
-    KIOCORE_EXPORT friend QDataStream &operator>> (QDataStream &s, KFileItem &a);
+    KIOCORE_EXPORT friend QDataStream &operator<<(QDataStream &s, const KFileItem &a);
+    KIOCORE_EXPORT friend QDataStream &operator>>(QDataStream &s, KFileItem &a);
 
     friend class KFileItemTest;
     friend class KCoreDirListerCache;
@@ -605,6 +607,10 @@ public:
     /// Creates a new KFileItemList from a QList of file @p items.
     KFileItemList(const QList<KFileItem> &items);
 
+    /// Creates a new KFileItemList from an initializer_list of file @p items.
+    /// @since 5.76
+    KFileItemList(std::initializer_list<KFileItem> items);
+
     /**
      * Find a KFileItem by name and return it.
      * @return the item with the given name, or a null-item if none was found
@@ -629,8 +635,8 @@ public:
     // TODO KDE-5 add d pointer here so that we can merge KFileItemListProperties into KFileItemList
 };
 
-KIOCORE_EXPORT QDataStream &operator<< (QDataStream &s, const KFileItem &a);
-KIOCORE_EXPORT QDataStream &operator>> (QDataStream &s, KFileItem &a);
+KIOCORE_EXPORT QDataStream &operator<<(QDataStream &s, const KFileItem &a);
+KIOCORE_EXPORT QDataStream &operator>>(QDataStream &s, KFileItem &a);
 
 /**
  * Support for qDebug() << aFileItem
